@@ -1,6 +1,4 @@
 /*
- * $Id: ddp_var.h,v 1.2 2001-06-29 14:14:47 rufustfirefly Exp $
- *
  * Copyright (c) 1990,1994 Regents of The University of Michigan.
  * All Rights Reserved.  See COPYRIGHT.
  */
@@ -21,16 +19,16 @@ struct ddpcb {
 #define sotoddpcb(so)	((struct ddpcb *)(so)->so_pcb)
 
 struct ddpstat {
-    u_int32_t	ddps_short;		/* short header packets received */
-    u_int32_t	ddps_long;		/* long header packets received */
-    u_int32_t	ddps_nosum;		/* no checksum */
-    u_int32_t	ddps_badsum;		/* bad checksum */
-    u_int32_t	ddps_tooshort;		/* packet too short */
-    u_int32_t	ddps_toosmall;		/* not enough data */
-    u_int32_t	ddps_forward;		/* packets forwarded */
-    u_int32_t	ddps_encap;		/* packets encapsulated */
-    u_int32_t	ddps_cantforward;	/* packets rcvd for unreachable dest */
-    u_int32_t	ddps_nosockspace;	/* no space in sockbuf for packet */
+    uint32_t	ddps_short;		/* short header packets received */
+    uint32_t	ddps_long;		/* long header packets received */
+    uint32_t	ddps_nosum;		/* no checksum */
+    uint32_t	ddps_badsum;		/* bad checksum */
+    uint32_t	ddps_tooshort;		/* packet too short */
+    uint32_t	ddps_toosmall;		/* not enough data */
+    uint32_t	ddps_forward;		/* packets forwarded */
+    uint32_t	ddps_encap;		/* packets encapsulated */
+    uint32_t	ddps_cantforward;	/* packets rcvd for unreachable dest */
+    uint32_t	ddps_nosockspace;	/* no space in sockbuf for packet */
 };
 
 #ifdef KERNEL
